========
NY Times
========

.. figure:: icons/nytimes.png

Loads data from the New York Times article search API.

Signals
-------

**Inputs**:

-  (None)

**Outputs**:

-  **Corpus**

A corpus instance.

Description
-----------

No description yet for this widget.

Example
-------

No example yet for this widget.
